package com.example.playertime;

import com.google.gson.Gson;
import com.google.gson.JsonObject;
import com.google.gson.JsonParser;
import net.fabricmc.loader.api.FabricLoader;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.text.MessageFormat;
import java.util.HashMap;
import java.util.Map;

// 这个是gemini写的
public class LocalizationManager {
    private final Map<String, String> translations = new HashMap<>();
    private final String defaultLanguage = "zh_cn";

    public LocalizationManager(String languageCode) {
        loadLanguage(languageCode);
        if (!languageCode.equals(defaultLanguage)) {
            loadLanguage(defaultLanguage, true);
        }
    }

    private void loadLanguage(String languageCode) {
        loadLanguage(languageCode, false);
    }


    private void loadLanguage(String languageCode, boolean isFallback) {
        String resourcePath = String.format("assets/playertime/lang/%s.json", languageCode);
        try (InputStream is = FabricLoader.getInstance().getModContainer("playertime")
                .flatMap(container -> container.findPath(resourcePath))
                .map(path -> {
                    try {
                        return path.toUri().toURL().openStream();
                    } catch (Exception e) {
                        return null;
                    }
                })
                .orElse(null)) {

            if (is == null) {
                if (!isFallback) {
                    PlayerTimeMod.LOGGER.warn("[PlayerTime] Language file not found for code: {}", languageCode);
                }
                return;
            }

            try (InputStreamReader reader = new InputStreamReader(is, StandardCharsets.UTF_8)) {
                JsonObject json = JsonParser.parseReader(reader).getAsJsonObject();
                json.entrySet().forEach(entry -> {
                    // Only add if not already present (fallback won't overwrite primary)
                    if (!translations.containsKey(entry.getKey())) {
                        translations.put(entry.getKey(), entry.getValue().getAsString());
                    } else if (!isFallback) {
                        // If loading primary, overwrite fallback
                        translations.put(entry.getKey(), entry.getValue().getAsString());
                    }
                });
                PlayerTimeMod.LOGGER.info("[PlayerTime] Loaded {} language strings for code: {}", translations.size(), languageCode);
            }

        } catch (Exception e) {
            PlayerTimeMod.LOGGER.error("[PlayerTime] Failed to load language file for code: {}", languageCode, e);
        }
    }

    public String getString(String key) {
        return translations.getOrDefault(key, key);
    }

    public String getString(String key, Object... args) {
        String pattern = getString(key);
        try {
            return MessageFormat.format(pattern, args);
        } catch (IllegalArgumentException e) {
            PlayerTimeMod.LOGGER.error("[PlayerTime] Failed to format localization string for key: {}", key, e);
            return pattern;
        }
    }
}
